diff -Nru chirp-0.4.0/chirp/__init__.py chirp-0.4.1/chirp/__init__.py
--- chirp-0.4.0/chirp/__init__.py	2014-03-25 14:57:18.000000000 -0400
+++ chirp-0.4.1/chirp/__init__.py	2014-10-27 16:56:15.000000000 -0400
@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-CHIRP_VERSION="0.4.0"
+CHIRP_VERSION="0.4.1"
 
 import os
 import sys
diff -Nru chirp-0.4.0/chirp/uv5r.py chirp-0.4.1/chirp/uv5r.py
--- chirp-0.4.0/chirp/uv5r.py	2014-03-17 03:01:31.000000000 -0400
+++ chirp-0.4.1/chirp/uv5r.py	2014-10-27 16:56:15.000000000 -0400
@@ -360,6 +360,16 @@
         print "_firmware_version_from_image: " + util.hexprint(version)
     return version
 
+def _special_block_from_data(data, special_block_start, special_block_stop):
+    special_block_tag = data[special_block_start:special_block_stop]
+    return special_block_tag
+
+def _special_block_from_image(radio):
+    special_block = _special_block_from_data(radio.get_mmap(), 0x0CFA, 0x0D01)
+    if CHIRP_DEBUG:
+        print "_special_block_from_image: " + util.hexprint(special_block)
+    return special_block
+
 def _do_ident(radio, magic):
     serial = radio.pipe
     serial.setTimeout(1)
@@ -427,6 +437,11 @@
         version = block[48:64]
     return version
 
+def _get_radio_special_block(radio):
+    block = _read_block(radio, 0xCF0, 0x40)
+    special_block = block[2:9]
+    return special_block
+
 def _ident_radio(radio):
     for magic in radio._idents:
         error = None
@@ -479,13 +494,22 @@
 
     image_version = _firmware_version_from_image(radio)
     radio_version = _get_radio_firmware_version(radio)
-    print "Image is %s" % repr(image_version)
-    print "Radio is %s" % repr(radio_version)
+    print "Image Version is %s" % repr(image_version)
+    print "Radio Version is %s" % repr(radio_version)
 
     if not any(type in radio_version for type in BASETYPE_LIST):
         raise errors.RadioError("Unsupported firmware version: `%s'" %
                                 radio_version)
 
+    image_special_block = _special_block_from_image(radio)
+    radio_special_block = _get_radio_special_block(radio)
+    print "Image Special Block is " + util.hexprint(image_special_block)
+    print "Radio Special Block is " + util.hexprint(radio_special_block)
+
+    if image_special_block != radio_special_block:
+        raise errors.RadioError("Image not supported by radio: `%s'" %
+                                radio_special_block)
+
     # Main block
     for i in range(0x08, 0x1808, 0x10):
         _send_block(radio, i - 0x08, radio.get_mmap()[i:i + 0x10])
diff -Nru chirp-0.4.0/debian/changelog chirp-0.4.1/debian/changelog
--- chirp-0.4.0/debian/changelog	2014-06-26 14:59:21.000000000 -0400
+++ chirp-0.4.1/debian/changelog	2014-10-27 17:42:34.000000000 -0400
@@ -1,3 +1,11 @@
+chirp (0.4.1-1.0) unstable; urgency=medium
+
+  * Non-maintainer upload
+  * new upstream version fixing critical issue with some Baofeng radios
+    (Closes: #767029)
+
+ -- Antoine Beaupré <anarcat@debian.org>  Mon, 27 Oct 2014 17:08:43 -0400
+
 chirp (0.4.0-1) unstable; urgency=low
 
   * new upstream version, thanks to Christopher Knadle for his help with it
diff -Nru chirp-0.4.0/PKG-INFO chirp-0.4.1/PKG-INFO
--- chirp-0.4.0/PKG-INFO	2014-03-25 14:57:20.000000000 -0400
+++ chirp-0.4.1/PKG-INFO	2014-10-27 16:56:15.000000000 -0400
@@ -1,6 +1,6 @@
 Metadata-Version: 1.0
 Name: chirp
-Version: 0.4.0
+Version: 0.4.1
 Summary: UNKNOWN
 Home-page: UNKNOWN
 Author: UNKNOWN
